@@ -87,7 +87,7 @@ class DiscreteEnv(gym.Env):
     
     
     #recover action value using indexes from onerow
-    action0, action1, action2 = action
+    action0, action1, action2 = action[0], action[1], action[2]
     action_0, action_1, action_2 = self.onerow[action0], self.onerow[action1], self.onerow[action2]   
 
       
